@@ -454,8 +454,8 @@ class ApigatewayClient(AbstractClient):
 
     def DemoteServiceUsagePlan(self, request):
         """This API is used to demote a usage plan of a service in an environment to the API level.
-        To make authentication and throttling for a service take effect, you need to bind a usage plan to it. This API is used to query all usage plans bound to the service.
-        This operation will be denied if there are no APIs under a service.
+
+        This operation will be denied if there are no APIs under the service.
         This operation will also be denied if the current environment has not been published.
 
         :param request: Request instance for DemoteServiceUsagePlan.
@@ -484,7 +484,7 @@ class ApigatewayClient(AbstractClient):
 
 
     def DescribeApi(self, request):
-        """This API is used to query the detailed information of an API deployed in API Gateway.
+        """This API is used to query the details of an API deployed in API Gateway.
 
         :param request: Request instance for DescribeApi.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeApiRequest`
@@ -540,8 +540,8 @@ class ApigatewayClient(AbstractClient):
 
 
     def DescribeApiKey(self, request):
-        """This API is used to query key details.
-        After creating an API key, you can query its details using this API which will display its key.
+        """This API is used to query the details of a key.
+        After creating an API key, you can query its details by using this API.
 
         :param request: Request instance for DescribeApiKey.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeApiKeyRequest`
@@ -570,7 +570,7 @@ class ApigatewayClient(AbstractClient):
 
     def DescribeApiUsagePlan(self, request):
         """This API is used to query the details of API usage plans in a service.
-        To make authentication and throttling for a service takes effect, you need to bind usage plans to it. This API is used to query all usage plans bound to a service and APIs under it.
+        To make authentication and throttling for a service take effect, you need to bind a usage plan to it. This API is used to query all usage plans bound to a service and APIs under it.
 
         :param request: Request instance for DescribeApiUsagePlan.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeApiUsagePlanRequest`
@@ -682,8 +682,8 @@ class ApigatewayClient(AbstractClient):
 
 
     def DescribeServiceEnvironmentReleaseHistory(self, request):
-        """This API is used to query the release history of a service environment.
-        A service can only be used when it is published to an environment after creation. This API is used to query the release history of an environment under a service.
+        """This API is used to query the release history in a service environment.
+        A service can only be used when it is published to an environment after creation. This API is used to query the release history in an environment under a service.
 
         :param request: Request instance for DescribeServiceEnvironmentReleaseHistory.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeServiceEnvironmentReleaseHistoryRequest`
@@ -711,7 +711,7 @@ class ApigatewayClient(AbstractClient):
 
 
     def DescribeServiceEnvironmentStrategy(self, request):
-        """This API is used to display service throttling policies.
+        """This API is used to display a service throttling policy.
 
         :param request: Request instance for DescribeServiceEnvironmentStrategy.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeServiceEnvironmentStrategyRequest`
@@ -769,7 +769,7 @@ class ApigatewayClient(AbstractClient):
 
     def DescribeServiceSubDomainMappings(self, request):
         """This API is used to query the path mappings of a custom domain name.
-        In API Gateway, you can bind a custom domain name to a service and map the paths for it. You can custom different path mappings to up to 3 environments under the service. This API is used to query the list of path mappings of a custom domain name bound to a service.
+        In API Gateway, you can bind a custom domain name to a service and map its paths. You can customize different path mappings to up to 3 environments under the service. This API is used to query the list of path mappings of a custom domain name bound to a service.
 
         :param request: Request instance for DescribeServiceSubDomainMappings.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeServiceSubDomainMappingsRequest`
@@ -827,7 +827,7 @@ class ApigatewayClient(AbstractClient):
 
     def DescribeServiceUsagePlan(self, request):
         """This API is used to query the details of usage plans in a service.
-        To make authentication and throttling for a service take effect, you need to bind a usage plan to it. This API is used to query all usage plans bound to the service.
+        To make authentication and throttling for a service take effect, you need to bind a usage plan to it. This API is used to query all usage plans bound to a service.
 
         :param request: Request instance for DescribeServiceUsagePlan.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeServiceUsagePlanRequest`
@@ -941,7 +941,7 @@ class ApigatewayClient(AbstractClient):
 
 
     def DisableApiKey(self, request):
-        """This API is used to disable an API key pair.
+        """This API is used to disable an API key.
 
         :param request: Request instance for DisableApiKey.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.DisableApiKeyRequest`
@@ -969,7 +969,7 @@ class ApigatewayClient(AbstractClient):
 
 
     def EnableApiKey(self, request):
-        """This API is used to enable a disabled API key pair.
+        """This API is used to enable a disabled API key.
 
         :param request: Request instance for EnableApiKey.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.EnableApiKeyRequest`
@@ -997,7 +997,7 @@ class ApigatewayClient(AbstractClient):
 
 
     def GenerateApiDocument(self, request):
-        """This API is used to automatically generate API documentation and SDKs. A document and an SDK will be generated for each environment under each service, respectively.
+        """This API is used to automatically generate API documents and SDKs. One document and one SDK will be generated for each environment under each service, respectively.
 
         :param request: Request instance for GenerateApiDocument.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.GenerateApiDocumentRequest`
@@ -1081,7 +1081,7 @@ class ApigatewayClient(AbstractClient):
 
 
     def ModifyApiIncrement(self, request):
-        """This API is used to incrementally update an API and mainly called by programs (different from `ModifyApi`, which requires full API parameters be passed in and is suitable for being used with the console).
+        """This API is used to incrementally update an API and mainly called by programs (different from `ModifyApi`, which requires that full API parameters be passed in and is suitable for use in the console).
 
         :param request: Request instance for ModifyApiIncrement.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.ModifyApiIncrementRequest`
@@ -1137,7 +1137,7 @@ class ApigatewayClient(AbstractClient):
 
 
     def ModifyService(self, request):
-        """This API is used to modify the relevant information of a service. After a service is created, its name, description, and service type all can be modified.
+        """This API is used to modify the relevant information of a service. After a service is created, its name, description, and service type can be modified.
 
         :param request: Request instance for ModifyService.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.ModifyServiceRequest`
@@ -1193,7 +1193,7 @@ class ApigatewayClient(AbstractClient):
 
 
     def ModifySubDomain(self, request):
-        """This API is used to modify the path mapping in the custom domain name settings of the service. The path mapping rule can be modified before it is bound to the custom domain name.
+        """This API is used to modify the path mapping in the custom domain name settings of a service. The path mapping rule can be modified before it is bound to the custom domain name.
 
         :param request: Request instance for ModifySubDomain.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.ModifySubDomainRequest`
@@ -1363,7 +1363,7 @@ class ApigatewayClient(AbstractClient):
 
     def UnBindSubDomain(self, request):
         """This API is used to unbind a custom domain name.
-        After binding a custom domain name to a service using API Gateway, you can use this API to unbind it.
+        After binding a custom domain name to a service by using API Gateway, you can use this API to unbind it.
 
         :param request: Request instance for UnBindSubDomain.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.UnBindSubDomainRequest`
@@ -1392,7 +1392,7 @@ class ApigatewayClient(AbstractClient):
 
     def UnReleaseService(self, request):
         """This API is used to deactivate a service.
-        Only when a service is published to an environment can its APIs be called by callers. You can call this API to deactivate a service from the release environment. Once deactivated, the service cannot be called.
+        Only after a service is published to an environment can its APIs be called. You can call this API to deactivate a service in the release environment. Once deactivated, the service cannot be called.
 
         :param request: Request instance for UnReleaseService.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.UnReleaseServiceRequest`
@@ -1448,7 +1448,7 @@ class ApigatewayClient(AbstractClient):
 
 
     def UpdateService(self, request):
-        """This API is used to switch the running version published in an environment of a service to a specified version. After you create a service by using API Gateway and publish it to an environment, multiple versions will be generated during development. In this case, you can call this API to switch versions.
+        """This API is used to switch the running version of a service published in an environment to a specified version. After you create a service by using API Gateway and publish it to an environment, multiple versions will be generated during development. In this case, you can call this API to switch versions.
 
         :param request: Request instance for UpdateService.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.UpdateServiceRequest`
