@@ -1387,6 +1387,38 @@ class DescribeDatabasesResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeProjectsRequest(AbstractModel):
+    """DescribeProjects request structure.
+
+    """
+
+
+class DescribeProjectsResponse(AbstractModel):
+    """DescribeProjects response structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param Projects: Project list
+        :type Projects: list of Project
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.Projects = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Projects") is not None:
+            self.Projects = []
+            for item in params.get("Projects"):
+                obj = Project()
+                obj._deserialize(item)
+                self.Projects.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class GrantAccountPrivilegesRequest(AbstractModel):
     """GrantAccountPrivileges request structure.
 
@@ -1846,6 +1878,63 @@ class ParamModifyResult(AbstractModel):
         self.Code = params.get("Code")
 
 
+class Project(AbstractModel):
+    """Project description
+
+    """
+
+    def __init__(self):
+        """
+        :param ProjectId: Project ID
+        :type ProjectId: int
+        :param OwnerUin: The `uin` of the resource owner (root account)
+        :type OwnerUin: int
+        :param AppId: Application ID
+        :type AppId: int
+        :param Name: Project name
+        :type Name: str
+        :param CreatorUin: Creator `uin`
+        :type CreatorUin: int
+        :param SrcPlat: Source platform
+        :type SrcPlat: str
+        :param SrcAppId: Source `AppId`
+        :type SrcAppId: int
+        :param Status: Project status. 0: normal; -1: disabled; 3: default project.
+        :type Status: int
+        :param CreateTime: Creation time
+        :type CreateTime: str
+        :param IsDefault: Whether it is the default project. 1: yes; 0: no.
+        :type IsDefault: int
+        :param Info: Description
+        :type Info: str
+        """
+        self.ProjectId = None
+        self.OwnerUin = None
+        self.AppId = None
+        self.Name = None
+        self.CreatorUin = None
+        self.SrcPlat = None
+        self.SrcAppId = None
+        self.Status = None
+        self.CreateTime = None
+        self.IsDefault = None
+        self.Info = None
+
+
+    def _deserialize(self, params):
+        self.ProjectId = params.get("ProjectId")
+        self.OwnerUin = params.get("OwnerUin")
+        self.AppId = params.get("AppId")
+        self.Name = params.get("Name")
+        self.CreatorUin = params.get("CreatorUin")
+        self.SrcPlat = params.get("SrcPlat")
+        self.SrcAppId = params.get("SrcAppId")
+        self.Status = params.get("Status")
+        self.CreateTime = params.get("CreateTime")
+        self.IsDefault = params.get("IsDefault")
+        self.Info = params.get("Info")
+
+
 class ResetAccountPasswordRequest(AbstractModel):
     """ResetAccountPassword request structure.
 
